@@ -28,10 +28,16 @@ class HtmlWindow(GtkHTML):
 		GtkHTML.__init__(self)
 	
 	def load_url(self, html, url):
-		handle = html.begin(url)
+		if history: url = urllib.basejoin(history[-1], url)
+		print "load_url", url
 		history.append(url)
+		handle = html.begin()
+		self.request_url(html, url, handle)
+		html.end(handle, HTML_STREAM_OK)
 
 	def request_url(self, html, url, handle):
+		url = urllib.basejoin(history[-1], url)
+		print "Requesting url", url
 		if url == 'blank':
 			print "here"
 			source = "<html><body>foobar</body></html>"
@@ -49,6 +55,7 @@ class HtmlWindow(GtkHTML):
 			mime = headers.getheader('Content-type')
 			source = f.read()
 		html.write(handle, source)
+		
 
 	def anchor_track(self, html, info):
 		if info.href:
@@ -64,12 +71,10 @@ class HtmlWindow(GtkHTML):
 			entry.set_text(url)
 			status.set('')
 
-	def key_function(self, entry, event, html):
+	def entry_activate(self, entry, html):
 		url = entry.get_text()
-		if event.keyval == GDK.Return:
-			self.load_url(html, url)
-			del forward[:]
-			entry.emit_stop_by_name('key_press_event')
+		self.load_url(html, url)
+		del forward[:]
 
 	def do_back(self, _b):
 		forward.append(history[-1])
@@ -123,13 +128,14 @@ entry = GtkEntry()
 html.connect('url_requested', html.request_url)
 html.connect('link_clicked', html.load_url)
 
-entry.connect('key_press_event', html.key_function, html)
+entry.connect('activate', html.entry_activate, html)
 vbox.pack_start(entry, expand=FALSE)
 entry.show()
 
 html.set_usize(400, 400)
 
 sw = GtkScrolledWindow()
+sw.set_policy(POLICY_AUTOMATIC, POLICY_AUTOMATIC)
 sw.add(html)
 vbox.pack_start(sw)
 
@@ -145,7 +151,7 @@ win.set_statusbar(status)
 win.create_menus(menus)
 win.create_toolbar(toolbar)
 
-handle = html.begin("blank")
+html.load_empty()
 
 win.show_all()
 
