@@ -54,7 +54,7 @@ static PyObject *_wrap_zvt_term_set_color_scheme(PyObject *self, PyObject *args)
   }
   for (i = 0; i < 18; i++) {
     item = PyList_GetItem(colours, i);
-    if (!PyArg_ParseTuple(PyList_GetItem(colours, i), "(hhh)",
+    if (!PyArg_ParseTuple(PyList_GetItem(colours, i), "hhh",
 			  &red[i], &grn[i], &blu[i])) {
       PyErr_Clear();
       PyErr_SetString(PyExc_TypeError,"list items must be like (int,int,int)");
